Projects — Renku 0.1.0.dev20180518 documentation

Join us on GitHub

# Projects

Model objects representing projects.

class `renku.models.projects.` `Project`(name=None, created=NOTHING, updated=NOTHING, version='1')

  Represent a project.

  Type:

      "foaf:Project"

  Context:

      {
        "foaf": "http://xmlns.com/foaf/0.1/",
        "name": "foaf:name",
        "created": "http://schema.org/dateCreated",
        "updated": "http://schema.org/dateUpdated",
        "version": "http://schema.org/schemaVersion"
      }

class `renku.models.projects.` `ProjectCollection`(client=None)

  Represent projects on the server.

  Example

  Create a project and check its name.

  # >>> project = client.projects.create(name=’test-project’) # >>> project.name # ‘test-project’

  Create a representation of objects on the server.

  class `Meta`

    Information about individual projects.

    `model`

      alias of `Project`

  `create`(name=None, **kwargs)

    Create a new project.

    Parameters: | name – The name of the project.
    Returns: | An instance of the newly create project.
    Return type: | Project